==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/PolicyListFluent.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface PolicyListFluent<A extends PolicyListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,Policy item);
    public A setToItems(int index,Policy item);
    public A addToItems(Policy... items);
    public A addAllToItems(Collection<Policy> items);
    public A removeFromItems(Policy... items);
    public A removeAllFromItems(Collection<Policy> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Policy> getItems();
    public List<Policy> buildItems();
    public Policy buildItem(int index);
    public Policy buildFirstItem();
    public Policy buildLastItem();
    public Policy buildMatchingItem(Predicate<PolicyBuilder> predicate);
    public A withItems(List<Policy> items);
    public A withItems(Policy... items);
    public Boolean hasItems();
    public PolicyListFluent.ItemsNested<A> addNewItem();
    public PolicyListFluent.ItemsNested<A> addNewItemLike(Policy item);
    public PolicyListFluent.ItemsNested<A> setNewItemLike(int index,Policy item);
    public PolicyListFluent.ItemsNested<A> editItem(int index);
    public PolicyListFluent.ItemsNested<A> editFirstItem();
    public PolicyListFluent.ItemsNested<A> editLastItem();
    public PolicyListFluent.ItemsNested<A> editMatchingItem(Predicate<PolicyBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,PolicyFluent<PolicyListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/PolicyListFluent.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface PolicyListFluent<A extends PolicyListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,Policy item);
    public A setToItems(int index,Policy item);
    public A addToItems(Policy... items);
    public A addAllToItems(Collection<Policy> items);
    public A removeFromItems(Policy... items);
    public A removeAllFromItems(Collection<Policy> items);
    public A removeMatchingFromItems(Predicate<PolicyBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<Policy> getItems();
    public List<Policy> buildItems();
    public Policy buildItem(int index);
    public Policy buildFirstItem();
    public Policy buildLastItem();
    public Policy buildMatchingItem(Predicate<PolicyBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<PolicyBuilder> predicate);
    public A withItems(List<Policy> items);
    public A withItems(Policy... items);
    public Boolean hasItems();
    public PolicyListFluent.ItemsNested<A> addNewItem();
    public PolicyListFluent.ItemsNested<A> addNewItemLike(Policy item);
    public PolicyListFluent.ItemsNested<A> setNewItemLike(int index,Policy item);
    public PolicyListFluent.ItemsNested<A> editItem(int index);
    public PolicyListFluent.ItemsNested<A> editFirstItem();
    public PolicyListFluent.ItemsNested<A> editLastItem();
    public PolicyListFluent.ItemsNested<A> editMatchingItem(Predicate<PolicyBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,PolicyFluent<PolicyListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
